@@ -33,6 +33,10 @@
 #include <ucommon/platform.h>
 #endif
 
+#ifndef _UCOMMON_GENERICS_H_
+#include <ucommon/generics.h>
+#endif
+
 #include <stdlib.h>
 
 NAMESPACE_UCOMMON
@@ -148,38 +152,6 @@ public:
     void release(void);
 };
 
-/**
- * Used as base class for temporary objects.  Temporary objects may be
- * allocated from the heap within a method call and removed automatically
- * removed when a method call completes.  This base class is meant to be
- * used in conjunction with an auto (stack frame) object referenced through
- * the auto_delete class as managed through the temporary template.
- * @author David Sugar <dyfet@gnutelephony.org>
- */
-class __EXPORT Temporary
-{
-protected:
-    friend class auto_delete;
-    virtual ~Temporary();
-};
-
-/**
- * A helper class for the temporary object template.  This class is assumed
- * to be created as an auto variable that will contain a pointer to an
- * object built from the Temporary base class.  When auto_delete falls out
- * of scope as a member function exits it deletes the heap based Temporary
- * object as well.
- * @author David Sugar <dyfet@gnutelephony.org>
- */
-class __EXPORT auto_delete
-{
-protected:
-    Temporary *object;
-
-public:
-    ~auto_delete();
-};
-
 /**
  * A general purpose smart pointer helper class.  This is particularly
  * useful in conjunction with reference counted objects which can be
@@ -190,33 +162,33 @@ public:
  * This is actually a helper class for the typed pointer template.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT auto_pointer
+class __EXPORT auto_object
 {
 protected:
     Object *object;
 
-    auto_pointer();
+    auto_object();
 
 public:
     /**
      * Construct an auto-pointer referencing an existing object.
      * @param object we point to.
      */
-    auto_pointer(Object *object);
+    auto_object(Object *object);
 
     /**
      * Construct an auto-pointer as a copy of another pointer.  The
      * retention of the object being pointed to will be increased.
      * @param pointer we are a copy of.
      */
-    auto_pointer(const auto_pointer &pointer);
+    auto_object(const auto_object &pointer);
 
     /**
      * Delete auto pointer.  When it falls out of scope, the retention
      * of the object it references is reduced.  If it falls to zero in
      * a reference counted object, then the object is auto-deleted.
      */
-    ~auto_pointer();
+    ~auto_object();
 
     /**
      * Manually release the pointer.  This reduces the retention level
@@ -358,43 +330,6 @@ private:
         {return new T;};
 };
 
-/**
- * Manage temporary object stored on the heap.  This is used to create a
- * object on the heap who's scope is controlled by the scope of a member
- * function call.  Sometimes we have data types and structures which cannot
- * themselves appear as auto variables.  We may also have a limited stack
- * frame size in a thread context, and yet have a dynamic object that we
- * only want to exist during the life of the method call.  Using temporary
- * allows any type to be created from the heap but have a lifespan of a
- * method's stack frame.  All types managed as temporary must have Temporary
- * as a base class.
- * @author David Sugar <dyfet@gnutelephony.org>
- */
-template <class T>
-class temporary : public auto_delete
-{
-public:
-    /**
-     * Construct a temporary object, create our stack frame reference.
-     */
-    inline temporary()
-        {object = new T;};
-
-    /**
-     * Access heap object through our temporary directly.
-     * @return reference to heap resident object.
-     */
-    inline T& operator*() const
-        {return *(static_cast<T*>(object));};
-
-    /**
-     * Access members of our heap object through our temporary.
-     * @return member reference of heap object.
-     */
-    inline T* operator->() const
-        {return static_cast<T*>(object);};
-};
-
 /**
  * Template for embedding a data structure into a reference counted object.
  * This is a convenient means to create reference counted heap managed data
@@ -474,20 +409,20 @@ public:
  * they are contained in remains in scope as well.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-template <class T, class P = auto_pointer>
-class pointer : public P
+template <class T, class P = auto_object>
+class object_pointer : public P
 {
 public:
     /**
      * Create a pointer with no reference.
      */
-    inline pointer() : P() {};
+    inline object_pointer() : P() {};
 
     /**
      * Create a pointer with a reference to a heap object.
      * @param object we are referencing.
      */
-    inline pointer(T* object) : P(object) {};
+    inline object_pointer(T* object) : P(object) {};
 
     /**
      * Reference object we are pointing to through pointer indirection.
@@ -537,6 +472,18 @@ public:
      */
     inline void operator=(T *typed)
         {P::operator=((Object *)typed);};
+
+    /**
+     * See if pointer is set.
+     */
+    inline operator bool()
+        {return P::object != NULL;};
+
+    /**
+     * See if pointer is not set.
+     */
+    inline bool operator!()
+        {return P::object == NULL;};
 };
 
 /**
@@ -560,69 +507,6 @@ inline void release(Object *object)
 inline Object *copy(Object *object)
     {return object->copy();}
 
-/**
- * Convenience function to validate object assuming it is castable to bool.
- * @param object we are testing.
- * @return true if object valid.
- */
-template<class T>
-inline bool is(T& object)
-    {return object.operator bool();}
-
-
-/**
- * Convenience function to test pointer object.  This solves issues where
- * some compilers get confused between bool and pointer operators.
- * @param object we are testing.
- * @return true if object points to NULL.
- */
-template<class T>
-inline bool isnull(T& object)
-    {return (bool)(object.operator*() == NULL);}
-
-/**
- * Convenience function to test pointer-pointer object.  This solves issues
- * where some compilers get confused between bool and pointer operators.
- * @param object we are testing.
- * @return true if object points to NULL.
- */
-template<class T>
-inline bool isnullp(T *object)
-    {return (bool)(object->operator*() == NULL);}
-
-/**
- * Convenience function to swap objects.
- * @param o1 to swap.
- * @param o2 to swap.
- */
-template<typename T>
-inline void swap(T& o1, T& o2)
-    {cpr_memswap(&o1, &o2, sizeof(T));}
-
-/**
- * Convenience function to return max of two objects.
- * @param o1 to check.
- * @param o2 to check.
- * @return max object.
- */
-template<typename T>
-inline T& (max)(T& o1, T& o2)
-{
-    return o1 > o2 ? o1 : o2;
-}
-
-/**
- * Convenience function to return min of two objects.
- * @param o1 to check.
- * @param o2 to check.
- * @return min object.
- */
-template<typename T>
-inline T& (min)(T& o1, T& o2)
-{
-    return o1 < o2 ? o1 : o2;
-}
-
 END_NAMESPACE
 
 #endif
